==> mybb-1.4.10_1.tbz: www/mybb/inc/languages/english/private.lang.php <==
<?php
/**
 * MyBB 1.4 English Language Pack
 * Copyright © 2008 MyBB Group, All Rights Reserved
 *
 * $Id: private.lang.php 4304 2009-01-02 01:11:56Z chris $
 */

$l['nav_pms'] = "Private Messages";
$l['nav_send'] = "Compose";
$l['nav_tracking'] = "Message Tracking";
$l['nav_folders'] = "Folder Management";
$l['nav_empty'] = "Empty Folders";
$l['nav_export'] = "Export Messages";

$l['new_pm'] = "New Message";
$l['old_pm'] = "Old Message";
$l['reply_pm'] = "Replied To";
$l['fwd_pm'] = "Forwarded Message";

$l['pms_disabled'] = "You cannot use the private messaging functionality as it has been disabled by the Administrator.";

$l['private_messaging'] = "Private Messaging";
$l['inbox'] = "Inbox";
$l['compose_message'] = "Compose Message";
$l['manage_folders'] = "Manage Folders";
$l['pms_in_folder'] = "Private Messages in folder <em>{1}</em>";
$l['message_title'] = "Message Title";
$l['sender'] = "Sender";
$l['sentto'] = "Sent To";
$l['date_sent'] = "Date/Time Sent";
$l['delete_pm'] = "Delete";
$l['move_to'] = "Move To";
$l['or'] = "or";
$l['selected_messages'] = "the selected messages";
$l['go'] = "Go!";
$l['pmspaceused'] = "of PM space used.";
$l['jump_folder'] = "Jump to Folder:";
$l['archive_messages'] = "Export Private Messages";
$l['archive_note'] = "The following tool will let you mass download your private messages out of a selected folder, messages sent after a particular date, your read messages, and drafted messages for later viewing.";
$l['folders'] = "Folders:";
$l['all_folders'] = "All Folders";
$l['date_limit'] = "Date Limitation:";
$l['date_limit_older'] = "Export messages older than";
$l['date_limit_newer'] = "Export messages newer than";
$l['date_limit_disregard'] = "Disregard date";
$l['date_limit_days'] = "days";
$l['export_unread'] = "Export Unread Messages?";
$l['delete_archived'] = "Delete Exported Messages?";
$l['delete_archived_note'] = "Do you want to delete the messages from your folders once they have been exported?";
$l['export_format'] = "Export File Format";
$l['export_format_note'] = "Please choose the file type of which to download attachments.";
$l['export_html'] = "HTML File (.html)";
$l['export_txt'] = "Text File (.txt)";
$l['export_csv'] = "Importable MS Excel File (.csv)";
$l['private_messages_for'] = "Private Messages for {1}";
$l['exported_date']  = "Exported: {1}, {2}";
$l['subject'] = "Subject:";
$l['to'] = "To:";
$l['from'] = "From:";
$l['sent'] = "Sent:";
$l['export_messages2'] = "Download Messages";
$l['empty_folders'] = "Empty Private Messaging Folders";
$l['empty_folders2'] = "Empty Folders";
$l['empty_note'] = "Here you can delete private messages from selected folders at one time. Simply select the folders you wish the messages to be deleted from and click 'Delete'. You cannot undo these changes.<br /><strong>Note: Once these messages are deleted there is no way to recover them.</strong>";
$l['num_messages'] = "No. Messages:";
$l['nobody'] = "Nobody";
$l['empty_q'] = "Empty?";
$l['keep_unread'] = "Keep Unread Messages";
$l['pm_folders'] = "Private Messaging Folders";
$l['existing_folders'] = "Existing Folders";
$l['edit_folder_note'] = "You can change the names of your current private messaging folders here. To delete a folder, delete the name of the folder. Some folders cannot be removed.<br /><strong>Note: Deleting a folder will also delete any messages in it.</strong>";
$l['new_folders'] = "Add New Folders";
$l['add_folders_note'] = "Here you can create additional message folders. You do not have to fill in all of the text boxes.";
$l['update_folders'] = "Update Folders";
$l['cannot_be_removed'] = "Cannot be removed";
$l['reached_warning'] = "Warning. You have reached your message limit.";
$l['reached_warning2'] = "To be able to receive messages you will need to delete old messages.";
$l['deny_receipt'] = "[deny receipt]";
$l['viewing_pm'] = "Viewing PM:";
$l['reply'] = "Reply";
$l['reply_to_all'] = "Reply to All";
$l['forward'] = "Forward";
$l['compose_pm'] = "Compose a Private Message";
$l['compose_to'] = "Recipients:";
$l['compose_bcc'] = "BCC:";
$l['compose_bcc_show'] = "BCC";
$l['compose_bcc_show_title'] = "Show the BCC input box allowing you to blind carbon copy messages to other users.";
$l['separate_names'] = "Separate multiple user names with a comma.";
$l['max_recipients'] = "<br />You may send this message to a maximum of <strong>{1}</strong> people.";
$l['compose_subject'] = "Subject:";
$l['compose_message2'] = "Compose Message";
$l['compose_message'] = "Message:";
$l['compose_options'] = "Options:";
$l['options_sig'] = "<strong>Signature:</strong> include your signature in this message.";
$l['options_disable_smilies'] = "<strong>Disable Smilies:</strong> disable smilies from showing in this message.";
$l['options_save_copy'] = "<strong>Save a Copy:</strong> save a copy of this message in your Sent Items folder.";
$l['options_read_receipt'] = "<strong>Request Read Receipt:</strong> receive a message when this message is read.";
$l['send_message'] = "Send Message";
$l['save_draft'] = "Save as Draft";
$l['preview'] = "Preview";
$l['select_buddy'] = "Or Select a Buddy:";
$l['pm_tracking'] = "Private Message Tracking";
$l['read_messages'] = "Read Messages";
$l['unread_messages'] = "Unread Messages";
$l['q'] = "?";
$l['dateread'] = "Date Read";
$l['stop_tracking'] = "Stop Tracking";
$l['datesent'] = "Date Sent";
$l['cancel'] = "Cancel";
$l['export_date_sent'] = "Date";
$l['export_folder'] = "Folder";
$l['export_subject'] = "Subject";
$l['export_to'] = "To";
$l['export_from'] ="From";
$l['export_message'] = "Message";
$l['not_sent'] = "N/A (not sent)";
$l['at'] = "at";
$l['nomessages'] = "There are no private messages in this folder.";
$l['details'] = "Details";
$l['message'] = "Message";
$l['buddy_list'] = "Buddy List";
$l['multiple_recipients'] = "<em>Multiple recipients</em>";
$l['bcc'] = "BCC:";
$l['reply_title'] = "Reply to this private message";
$l['forward_title'] = "Forward this private message to another user";
$l['delete_title'] = "Delete this private message";
$l['you_replied_on'] = "You replied to this message on {1}";
$l['you_forwarded_on'] = "You forwarded this message on {1}";
$l['you_replied'] = "You replied to this message {1}";
$l['you_forwarded'] = "You forwarded this message {1}";
$l['select_from_buddies'] = "Select from Buddies";
$l['no_readmessages'] = "You currently do not have any read messages being tracked.";
$l['no_unreadmessages'] = "You currently do not have any unread messages being tracked.";

$l['error_nopmsarchive'] = "Sorry, but there are no private messages matching the criteria you specified.";
$l['error_invalidpmfoldername'] = "Sorry, but a folder name you have entered contains characters which are not allowed.";
$l['error_emptypmfoldername'] = "Sorry, but a folder name you have entered does not contain any text.  Please enter a name for the folder, or completely blank the name to delete the folder.";
$l['error_invalidpmrecipient'] = "The recipient you entered is either invalid or doesn't exist. Please go back and enter a correct one.";
$l['error_invalidpm'] = "Invalid PM";
$l['error_pmrecipientreachedquota'] = "You cannot send a private message to {1} because he/she has reached their private messaging quota. They cannot be sent any message until their messages have been cleared out. An email has been sent to the user about this. Please try sending your message at a later stage.";
$l['error_recipientpmturnedoff'] = "{1} has chosen not to receive private messages or may not be allowed to do so. Therefore you may not send your private message to this user.";
$l['error_pmsturnedoff'] = "You currently have private messages disabled in your profile.<br />To be able to use the private messaging system this setting must be enabled.";
$l['error_recipientignoring'] = "We are sorry but we cannot process your private message to {1}. You do not have permission to perform this action.";
$l['error_pm_already_submitted'] = "You have already submitted the same private message to the same recipient within the last 5 minutes.";

$l['redirect_pmsaved'] = "The private message has been saved in your Drafts folder.";
$l['redirect_pmstrackingstopped'] = "Tracking of the selected PMs has been stopped.";
$l['redirect_pmstrackingcanceled'] = "The selected unread PMs have been deleted from the recipient's inbox.";
$l['redirect_pmsmoved'] = "The selected private messages have been moved.";
$l['redirect_pmsdeleted'] = "The selected private messages have been deleted.<br />You will now be returned to your PM Inbox.";
$l['redirect_pmsent'] = "Thank you, your private message has successfully been sent.<br />You will now be returned to your private message inbox.";
$l['redirect_pmfoldersupdated'] = "Thank you, your private messaging folders have successfully been updated.<br />You will now be returned to your private message Inbox.";
$l['redirect_pmfoldersemptied'] = "The selected private messaging folders have successfully been emptied.<br />You will now be taken back to your Private Messaging Inbox.";

?>

==> mybb-1.6.6.tbz: www/mybb/inc/languages/english/private.lang.php <==
<?php
/**
 * MyBB 1.6 English Language Pack
 * Copyright 2010 MyBB Group, All Rights Reserved
 *
 * $Id: private.lang.php 5608 2011-09-19 14:05:43Z Tomm $
 */

$l['nav_pms'] = "Private Messages";
$l['nav_send'] = "Compose";
$l['nav_tracking'] = "Message Tracking";
$l['nav_folders'] = "Folder Management";
$l['nav_empty'] = "Empty Folders";
$l['nav_export'] = "Export Messages";
$l['nav_search'] = "Search";
$l['nav_results'] = "Results";

$l['new_pm'] = "New Message";
$l['old_pm'] = "Old Message";
$l['reply_pm'] = "Replied To";
$l['fwd_pm'] = "Forwarded Message";

$l['pms_disabled'] = "You cannot use the private messaging functionality as it has been disabled by the Administrator.";

$l['private_messaging'] = "Private Messaging";
$l['inbox'] = "Inbox";
$l['compose_message2'] = "Compose Message";
$l['manage_folders'] = "Manage Folders";
$l['pms_in_folder'] = "Private Messages in folder <em>{1}</em>";
$l['pm_search_results'] = "Private Message Search Results";
$l['message_title'] = "Message Title";
$l['sender'] = "Sender";
$l['sentto'] = "Sent To";
$l['date_sent'] = "Date/Time Sent";
$l['delete_pm'] = "Delete";
$l['move_to'] = "Move To";
$l['or'] = "or";
$l['selected_messages'] = "the selected messages";
$l['go'] = "Go!";
$l['pmspaceused'] = "of PM space used.";
$l['jump_folder'] = "Jump to Folder:";
$l['archive_messages'] = "Export Private Messages";
$l['archive_note'] = "The following tool will let you mass download your private messages out of a selected folder, messages sent after a particular date, your read messages, and drafted messages for later viewing.";
$l['folders'] = "Folders:";
$l['all_folders'] = "All Folders";
$l['date_limit'] = "Date Limitation:";
$l['date_limit_older'] = "Export messages older than";
$l['date_limit_newer'] = "Export messages newer than";
$l['date_limit_disregard'] = "Disregard date";
$l['date_limit_days'] = "days";
$l['export_unread'] = "Export Unread Messages?";
$l['delete_archived'] = "Delete Exported Messages?";
$l['delete_archived_note'] = "Do you want to delete the messages from your folders once they have been exported?";
$l['export_format'] = "Export File Format";
$l['export_format_note'] = "Please choose the file type of which to download attachments.";
$l['export_html'] = "HTML File (.html)";
$l['export_txt'] = "Text File (.txt)";
$l['export_csv'] = "Importable MS Excel File (.csv)";
$l['private_messages_for'] = "Private Messages for {1}";
$l['exported_date']  = "Exported: {1}, {2}";
$l['subject'] = "Subject:";
$l['to'] = "To:";
$l['from'] = "From:";
$l['sent'] = "Sent:";
$l['export_messages2'] = "Download Messages";
$l['empty_folders'] = "Empty Private Messaging Folders";
$l['empty_folders2'] = "Empty Folders";
$l['empty_note'] = "Here you can delete private messages from selected folders at one time. Simply select the folders you wish the messages to be deleted from and click 'Delete'. You cannot undo these changes.<br /><strong>Note: Once these messages are deleted there is no way to recover them.</strong>";
$l['num_messages'] = "No. Messages:";
$l['nobody'] = "Nobody";
$l['empty_q'] = "Empty?";
$l['keep_unread'] = "Keep Unread Messages";
$l['pm_folders'] = "Private Messaging Folders";
$l['existing_folders'] = "Existing Folders";
$l['edit_folder_note'] = "You can change the names of your current private messaging folders here. To delete a folder, delete the name of the folder. Some folders cannot be removed.<br /><strong>Note: Deleting a folder will also delete any messages in it.</strong>";
$l['new_folders'] = "Add New Folders";
$l['add_folders_note'] = "Here you can create additional message folders. You do not have to fill in all of the text boxes.";
$l['update_folders'] = "Update Folders";
$l['cannot_be_removed'] = "Cannot be removed";
$l['reached_warning'] = "Warning. You have reached your message limit.";
$l['reached_warning2'] = "To be able to receive messages you will need to delete old messages.";
$l['deny_receipt'] = "[deny receipt]";
$l['viewing_pm'] = "Viewing PM:";
$l['reply'] = "Reply";
$l['reply_to_all'] = "Reply to All";
$l['forward'] = "Forward";
$l['compose_pm'] = "Compose a Private Message";
$l['compose_to'] = "Recipients:";
$l['compose_bcc'] = "BCC:";
$l['compose_bcc_show'] = "BCC";
$l['compose_bcc_show_title'] = "Show the BCC input box allowing you to blind carbon copy messages to other users.";
$l['separate_names'] = "Separate multiple user names with a comma.";
$l['max_recipients'] = "<br />You may send this message to a maximum of <strong>{1}</strong> people.";
$l['compose_subject'] = "Subject:";
$l['compose_message'] = "Message:";
$l['compose_options'] = "Options:";
$l['options_sig'] = "<strong>Signature:</strong> include your signature in this message.";
$l['options_disable_smilies'] = "<strong>Disable Smilies:</strong> disable smilies from showing in this message.";
$l['options_save_copy'] = "<strong>Save a Copy:</strong> save a copy of this message in your Sent Items folder.";
$l['options_read_receipt'] = "<strong>Request Read Receipt:</strong> receive a message when this message is read.";
$l['send_message'] = "Send Message";
$l['save_draft'] = "Save as Draft";
$l['preview'] = "Preview";
$l['select_buddy'] = "Or Select a Buddy:";
$l['pm_tracking'] = "Private Message Tracking";
$l['read_messages'] = "Read Messages";
$l['unread_messages'] = "Unread Messages";
$l['q'] = "?";
$l['dateread'] = "Date Read";
$l['stop_tracking'] = "Stop Tracking";
$l['datesent'] = "Date Sent";
$l['cancel'] = "Cancel";
$l['export_date_sent'] = "Date";
$l['export_folder'] = "Folder";
$l['export_subject'] = "Subject";
$l['export_to'] = "To";
$l['export_from'] ="From";
$l['export_message'] = "Message";
$l['not_sent'] = "N/A (not sent)";
$l['at'] = "at";
$l['nomessages'] = "There are no private messages in this folder.";
$l['details'] = "Details";
$l['message'] = "Message";
$l['buddy_list'] = "Buddy List";
$l['multiple_recipients'] = "<em>Multiple recipients</em>";
$l['bcc'] = "BCC:";
$l['reply_title'] = "Reply to this private message";
$l['forward_title'] = "Forward this private message to another user";
$l['delete_title'] = "Delete this private message";
$l['you_replied_on'] = "You replied to this message on {1}";
$l['you_forwarded_on'] = "You forwarded this message on {1}";
$l['you_replied'] = "You replied to this message {1}";
$l['you_forwarded'] = "You forwarded this message {1}";
$l['select_from_buddies'] = "Select from Buddies";
$l['no_readmessages'] = "You currently do not have any read messages being tracked.";
$l['no_unreadmessages'] = "You currently do not have any unread messages being tracked.";

$l['enter_keywords'] = "Enter Keywords";
$l['advanced_search'] = "Advanced Search";
$l['search_pms'] = "Search PMs";
$l['advanced_private_message_search'] = "Advanced Private Message Search";
$l['search_criteria'] = "Search Criteria";
$l['keywords'] = "Keywords";
$l['search_in_subject'] = "Search in Subject";
$l['search_in_message'] = "Search in Message";
$l['message_status'] = "Message Status";
$l['message_status_new'] = "New";
$l['message_status_replied_to'] = "Replied to";
$l['message_status_forwarded'] = "Forwarded";
$l['message_status_read'] = "Read";
$l['folder'] = "Folder";
$l['search_options'] = "Search Options";
$l['sort_by'] = "Sort By";
$l['sort_by_subject'] = "Sort By: Subject";
$l['sort_by_sender'] = "Sort By: Sender";
$l['sort_by_date'] = "Sort By: Date";
$l['ascending_order'] = "Ascending Order";
$l['descending_order'] = "Descending Order";
$l['search_private_messages'] = "Search Private Messages";
$l['check_all'] = "Check All";

$l['error_nopmsarchive'] = "Sorry, but there are no private messages matching the criteria you specified.";
$l['error_invalidpmfoldername'] = "Sorry, but a folder name you have entered contains characters which are not allowed.";
$l['error_emptypmfoldername'] = "Sorry, but a folder name you have entered does not contain any text.  Please enter a name for the folder, or completely blank the name to delete the folder.";
$l['error_invalidpmrecipient'] = "The recipient you entered is either invalid or doesn't exist. Please go back and enter a correct one.";
$l['error_invalidpm'] = "Invalid PM";
$l['error_pmrecipientreachedquota'] = "You cannot send a private message to {1} because he/she has reached their private messaging quota. They cannot be sent any message until their messages have been cleared out. An email has been sent to the user about this. Please try sending your message at a later stage.";
$l['error_recipientpmturnedoff'] = "{1} has chosen not to receive private messages or may not be allowed to do so. Therefore you may not send your private message to this user.";
$l['error_pmsturnedoff'] = "You currently have private messages disabled in your profile.<br />To be able to use the private messaging system this setting must be enabled.";
$l['error_recipientignoring'] = "We are sorry but we cannot process your private message to {1}. You do not have permission to perform this action.";
$l['error_pm_already_submitted'] = "You have already submitted the same private message to the same recipient within the last 5 minutes.";

$l['error_minsearchlength'] = "One or more of your search terms were shorter than the minimum length. The minimum search term length is {1} characters.<br /><br />If you're trying to search for an entire phrase, enclose it within double quotes. For example \"The quick brown fox jumps over the lazy dog\".";
$l['error_nosearchresults'] = "Sorry, but no results were returned using the query information you provided. Please redefine your search terms and try again.";
$l['error_no_search_support'] = "This database engine does not support searching.";
$l['error_nosearchterms'] = "You did not enter any search terms. At a minimum, you must enter either some search terms or a username to search by.";
$l['error_searchflooding_1'] = "Sorry, but you can only perform one search every {1} seconds. Please wait another 1 second before attempting to search again.";
$l['error_searchflooding'] = "Sorry, but you can only perform one search every {1} seconds. Please wait another {2} seconds before attempting to search again.";
$l['error_invalidsearch'] = "An invalid search was specified.  Please go back and try again.";

$l['redirect_pmsaved'] = "The private message has been saved in your Drafts folder.";
$l['redirect_pmstrackingstopped'] = "Tracking of the selected PMs has been stopped.";
$l['redirect_pmstrackingcanceled'] = "The selected unread PMs have been deleted from the recipient's inbox.";
$l['redirect_pmsmoved'] = "The selected private messages have been moved.";
$l['redirect_pmsdeleted'] = "The selected private messages have been deleted.";
$l['redirect_pmsent'] = "Thank you, your private message has successfully been sent.<br />You will now be returned to your private message inbox.";
$l['redirect_pmfoldersupdated'] = "Thank you, your private messaging folders have successfully been updated.<br />You will now be returned to your private message Inbox.";
$l['redirect_pmfoldersemptied'] = "The selected private messaging folders have successfully been emptied.<br />You will now be taken back to your Private Messaging Inbox.";
$l['redirect_searchresults'] = "Thank you, your search has been submitted and you will now be taken to the results list.";

?>
